@@ -1,6 +1,6 @@
 #include "qrsink.h"
 #include <mbarcode-qt/plugininterfaces.h>
-#include <mbarcode-qt/sinkplugin.h>
+#include <mbarcode-qt/pluginaction.h>
 
 #include <QtCore>
 #include <QProcess>
@@ -29,8 +29,10 @@
 //#include <libosso-abook/osso-abook-contact.h>
 //#include <libosso-abook/osso-abook-util.h>
 
-QrSink::QrSink(const PluginInterface *interface) : SinkPlugin(interface) {
+QrSink::QrSink(const PluginInterface *interface) : PluginAction(interface) {
     ready = false;
+    image = QImage(":/images/qrcode.png");
+    image = image.scaledToHeight(48, Qt::SmoothTransformation);
 }
 
 QString QrSink::getText()
@@ -38,6 +40,10 @@ QString QrSink::getText()
     return buttonText;
 }
 
+QImage QrSink::getImage() {
+    return image;
+}
+
 void QrSink::clickAction(QWidget *parentWindow) {
      //QDBusInterface *interface = new QDBusInterface("com.nokia.osso_browser","/com/nokia/osso_browser/request",
      //                                               "com.nokia.osso_browser");
