@@ -4,28 +4,12 @@
 #include <QtCore>
 #include <QImage>
 #include <mbarcode-qt/plugininterfaces.h>
-#include <mbarcode-qt/sinkplugin.h>
+#include <mbarcode-qt/pluginaction.h>
 
-class QrSink : public QObject, public SinkPlugin
+class QrSink : public QObject, public PluginAction
 {
     Q_OBJECT
 public:
-    // inherited virtuals
-    QrSink(const PluginInterface *interface);
-    QString getName() {return "QR-code sink plugin";};
-    QString getText();
-    bool isReady();
-    void clickAction(QWidget *parentWindow);
-    // other
-    //QString url;
-private slots:
-    void barcodeAnalysed(QString barcodeType, QString barcodeData);
-private:
-    bool ready;
-    QString buttonText;
-    QString barcodeText;
-    int type;
-
     enum barcodeType {
         Unknown=0,
         Email,
@@ -41,11 +25,29 @@ private:
         Install,
         Ovi
     };
+    // inherited virtuals
+    QrSink(const PluginInterface *interface);
+    QString getName() {return "QR-code sink plugin";}
+    QString getText();
+    QImage getImage();
+    bool isReady();
+    void clickAction(QWidget *parentWindow);
+    // other
+    //QString url;
+private slots:
+    void barcodeAnalysed(QString barcodeType, QString barcodeData);
+private:
     void openGeneric(QString uri);
     void addVCard(QString user_data);
     void openInstallFile(QString data);
     void openBrowser(QString uri);
-    // other
+
+    bool ready;
+    QString buttonText;
+    QString barcodeText;
+    int type;
+
+    QImage image;
 };
 
 #endif // TESTSINK_H
